<?php
namespace Modules\Cotacao\Modules\AnaliseCotacoes\Controllers;

use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;

class Sup00600HistoricoComparativoCotacoesController extends \Zeedhi\Framework\Controller\Report {

    protected $entityManager;
    protected $qr2Strategy;
    protected $newCode;
    protected $environment;
    protected $connection;
    protected $dataSourceManager;
    protected $birtStrategy;
    protected $stNomeRel;

    public function __construct($reportService, $entityManager, $qr2Strategy,$dataSourceManager,$newCode, $environment, $connection,$birtStrategy) {

        $this->entityManager       = $entityManager;
        $this->qr2Strategy         = $qr2Strategy;
        $this->reportService       = $reportService;
        $this->dataSourceManager   = $dataSourceManager;
        $this->newCode             = $newCode;
        $this->environment         = $environment;
        $this->connection          = $connection;
        $this->birtStrategy       = $birtStrategy;
        
    }
    

    protected $reportMapping = array ();
     
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response){   
        $row = $request->getRow();
        $this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE']));
        $this->qr2Strategy->setQr2Type($row['QR2TYPE']);
        $this->stNomeRel = $this->getReportName($row);
        
        $row['P_NRORG'] = $this->environment->getNrOrg();
        $tipoRelatorio = $row['STRATEGY'];
        if($tipoRelatorio == "BIRT"){
            if($this->stNomeRel=='SUP00600' || $this->stNomeRel=='SUP00603'){
                $paramRelatorio = array (
                    "REGIAO"            => "L_CDREGIAO",
                    "FORNECEDOR"        => "L_CDFORNECED",
                    "CDARVPRODINI"      => "P_CDINI",
                    "CDARVPRODFIM"      => "P_CDFIN",
                    "DTINI"             => "P_DTINICIAL", 
                    "DTFIN"             => "P_DTFINAL",
                    "P_NRORG"           => "P_NRORG"
                );
            } 
            
            if($this->stNomeRel=='SUP00601'|| $this->stNomeRel=='SUP00602'){
                // REGIÃO
                if($row['REGIAO'] != 'T'){
                    $nrlista = $this->criarListaValores($row['REGIAO']);   
                    $row['REGIAO'] = "_NRLISTA=".$nrlista;
                }
                
                // FORNECEDOR
                if($row['FORNECEDOR'] != 'T'){
                    $nrlista = $this->criarListaValores($row['FORNECEDOR']);   
                    $row['FORNECEDOR'] = "_NRLISTA=".$nrlista;
                }
                
                // UNIDADE
                if($row['CDFILIAL'] != 'T'){
                    $nrlista = $this->criarListaValores($row['CDFILIAL']);   
                    $row['CDFILIAL'] = "_NRLISTA=".$nrlista;
                }
            
                $paramRelatorio = array (
                    "REGIAO"            => "L_CDREGIAO",
                    "CDFILIAL"          => "L_CDFILIAL",
                    "FORNECEDOR"        => "L_CDFORNECED",
                    "CDARVPRODINI"      => "P_CDINI",
                    "CDARVPRODFIM"      => "P_CDFIN",
                    "DTINI"             => "P_DTINICIAL",
                    "DTFIN"             => "P_DTFINAL",
                    "P_NRORG"           => "P_NRORG"
                );
            }
        } else {
            $row['FORNECEDOR1'] = $row['FORNECEDOR'];
            $row['DTINI1'] = $row['DTINI'];
            $row['DTFIN1'] = $row['DTFIN'];
            $row['CDARVPRODINI1'] = $row['CDARVPRODINI'];
            $row['CDARVPRODFIM1'] = $row['CDARVPRODFIM'];
            $row['CDFILCENTCMP'] = $this->getCdFilCentCmp($row["CDFILIAL"]);
            $paramRelatorio = array (
                "DTINI"             => "P_DTINICIAL",
                "DTFIN"             => "P_DTFINAL",
                "FORNECEDOR"        => "L_CDFORNECED",
                "CDARVPRODINI"      => "P_CDINI",
                "CDARVPRODFIM"      => "P_CDFIN",
                "REGIAO"            => "L_CDREGIAO",
                "FORNECEDOR1"       => "L_CDFORNECED1",
                "DTINI1"            => "P_DTINI",
                "DTFIN1"            => "P_DTFIN",
                "CDARVPRODINI1"     => "P_CDPRODINI",
                "CDARVPRODFIM1"     => "P_CDPRODFIN",
                "CDFILIAL"          => "L_CDFILIAL",
                "CDFILCENTCMP"      => "L_CDFILCENTCMP"
            );
        }
        $this->reportMapping[$this->stNomeRel] =
        array(
            'strategy' => $tipoRelatorio,
            'parameterMapping' => $paramRelatorio
        );
    }

    
    
    //cria lista de valores recebendo string como parametro
    protected function criarListaValores($lista){
        $nrlista = $this->newCode->getCodeByTableName('LISTA', $this->environment->getNrOrg());
        $valores = explode('_',$lista);
        try{
            foreach($valores as $key){
                $this->insertLista($nrlista, $key);
            }
            return $nrlista;
        } catch(\Exception $e){
            throw $e;
        }
     }
    
    //insere lista no banco
    public function insertLista($nrlista, $cdlista) {
        $params = array(
            "NRLISTA" => $nrlista,
            "CDLISTA" => $cdlista
        );
        
        $sql = "INSERT INTO LISTA (NRLISTA, CDLISTA) VALUES (:NRLISTA, :CDLISTA)";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    
    public function getCdFilCentCmp($cdfilial) {
        $sql = "SELECT DISTINCT
          NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL)  AS CDFILIAL,
          FIL.NMFILIAL AS NMFILIAL_CENTRAL
        FROM
          FILIAL FIL,
          FILIAL
        WHERE
          INSTR(:P_CDFILIAL, FILIAL.CDFILIAL) <> 0       AND
          NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL) = FIL.CDFILIAL";
        $params = array(
            "P_CDFILIAL" => $cdfilial
        );
        $query = $this->connection->prepare($sql);
        $query->execute($params);

        $resultRows = $query->fetchAll();
        
        $filial = implode('_', array_map(function ($row) {
            return $row['CDFILIAL'];
        }, $resultRows));
        
        return $filial;
    }
}



   
  
        


