<?php

namespace Modules\Fornecimento\Modules\MigracaoAF\Services;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;

class MigracaoAFService {
    
    protected $connection;
    protected $newCode;
    
    public function __construct($entityManager, $environment, $newCode){
        $this->connection = $entityManager->getConnection();
        $this->environment = $environment;
        $this->newCode = $newCode;
    }
    
    public function criaFiltroCentralCompras(){
        $filter = array(
		    array(
    		    "columnName" => "P_CDFILIAL", 
    		    "value" => $this->environment->getCdFilial(),
    		    "operator" => "="
		    ),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    protected function NovoCodigo($tabela){
        return $this->newCode->getCodeByTableName($tabela, $this->environment->getNrorg());
    }
    
    protected function insertLista($lista, $cdfildest){
        $params = array(
            "NRLISTA" => $lista,
            "CDLISTA" => $cdfildest,
    		"NRORG" => $this->environment->getNrorg()
    	);
    	$query = "INSERT INTO LISTA (NRLISTA, CDLISTA, NRORG) VALUES (:NRLISTA, :CDLISTA, :NRORG)";
		try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    protected function insertListaGrupFili($lista, $cdgrupfili, $cdcentcmp){
        $params = array(
            "NRLISTA" => $lista,
            "P_CDGRUPFILI" => $cdgrupfili,
            "P_CDCENTCMP" => $cdcentcmp,
    		"NRORG" => $this->environment->getNrorg()
    	);
    	$query = "INSERT INTO LISTA (NRLISTA, CDLISTA, NRORG) (SELECT :NRLISTA, FILGRUPFILI.CDFILIAL, FILGRUPFILI.NRORG FROM FILGRUPFILI INNER JOIN (SELECT FILIAL.CDFILIAL, FILIAL.NRORG FROM FILIAL WHERE NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL) = NVL(:P_CDCENTCMP, NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL))) FILIAL ON FILGRUPFILI.CDFILIAL = FILIAL.CDFILIAL AND FILGRUPFILI.NRORG = FILIAL.NRORG WHERE FILGRUPFILI.CDGRUPFILI = :P_CDGRUPFILI AND FILGRUPFILI.NRORG = :NRORG)";
		try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    protected function insertListaFilCentCMP($lista, $cdcentcmp){
        $params = array(
            "NRLISTA" => $lista,
            "P_CDCENTCMP" => $cdcentcmp,
    		"NRORG" => $this->environment->getNrorg()
    	);
    	$query = "INSERT INTO LISTA (NRLISTA, CDLISTA, NRORG) (SELECT :NRLISTA, FILIAL.CDFILIAL, FILIAL.NRORG FROM FILIAL WHERE NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL) = NVL(:P_CDCENTCMP, NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL)) AND FILIAL.NRORG = :NRORG)";
		try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e){
            throw $e;
        }
    }

    public function ProximaListaFilial($row){
        $lista = $this->NovoCodigo('LISTA');
        /*if($row['naoConsideraCDFILDEST'] != 'T'){*/
            foreach ($row['CDFILDEST'] as $cdfildest){
                $this->insertLista($lista, $cdfildest);
            }
        /*} else {
            if($row['CDGRUPFILI'] != null){
                $this->insertListaGrupFili($lista, $row['CDGRUPFILI'], $row['CDFILCENTCMP']);
            } else {
                $this->insertListaFilCentCMP($lista, $row['CDFILCENTCMP']);
            }
        }*/
        return $lista;
    }
    
    public function criaFiltroMigracaoAF($row){
        if($row['naoConsideraCDFORNECED'] == 'T'){
            $stFornecedor = '';
        } else {
            $stFornecedor = '_';
            foreach ($row['CDFORNECED'] as $cdforneced){
                $stFornecedor .= $cdforneced .'_';
            }
        }
        $filter = array(
		    array(
    		    "columnName" => "P_CDFORNECED", 
    		    "value" => $stFornecedor,
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_NRLISTAFIL", 
    		    "value" => $this->ProximaListaFilial($row),
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_DTAUTFINI", 
    		    "value" => $row['DTAUTFINI'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_DTAUTFFIN", 
    		    "value" => $row['DTAUTFFIN'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_CDPRODINI", 
    		    "value" => $row['CDPRODINI'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_CDPRODFIN", 
    		    "value" => $row['CDPRODFIN'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_DTPROGENTAFINI", 
    		    "value" => $row['DTPROGENTAFINI'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_DTPROGENTAFFIN", 
    		    "value" => $row['DTPROGENTAFFIN'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_IDTPGERARUP", 
    		    "value" => $row['exibeRupturaOL'],
    		    "operator" => "="
		    ),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function criaFiltroItemCole($row){
        $filter = array(
		    array(
    		    "columnName" => "P_CDFORNECED", 
    		    "value" => $row['CDFORNECED'],
    		    "operator" => "="
		    ),
	        array(
    		    "columnName" => "P_CDPRODUTO", 
    		    "value" => $row['CDPRODUTO'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_CDMARCA", 
    		    "value" => $row['CDMARCA'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_CDFILDEST", 
    		    "value" => $row['CDFILDEST'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_DTPROGENTAF", 
    		    "value" => $row['DTPROGENTAF'],
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function criaFiltroProdAtivo($row){
        $filter = array(
	        array(
    		    "columnName" => "P_CDPRODUTO", 
    		    "value" => $row['CDPRODUTO'],
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function criaFiltroQualifMarca($row){
        $filter = array(
	        array(
    		    "columnName" => "P_CDPRODUTO", 
    		    "value" => $row['CDPRODUTO'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_CDMARCA", 
    		    "value" => $row['CDMARCA'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_CDFILIAL", 
    		    "value" => $row['CDFILCENTCMP'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_DTCOL", 
    		    "value" => $row['DTPROGENTAF'],
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function criaFiltroQualifMarcProd($row){
        $filter = array(
	        array(
    		    "columnName" => "P_CDPRODINI", 
    		    "value" => $row['CDARVPROD'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_CDMARCA", 
    		    "value" => $row['CDMARCA'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_CDFILIAL", 
    		    "value" => $row['CDFILCENTCMP'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_DTCOL", 
    		    "value" => $row['DTPROGENTAF'],
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function criaFiltroProdForneComp($row){
        $filter = array(
	        array(
    		    "columnName" => "P_CDFORNECED", 
    		    "value" => $row['CDFORNECED'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_CDPRODCOMPL", 
    		    "value" => $row['CDPRODUTO'],
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function criaFiltroReFoReg($row){
        $filter = array(
	        array(
    		    "columnName" => "P_CDFORNECED", 
    		    "value" => $row['CDFORNECED'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_CDFILDEST", 
    		    "value" => $row['CDFILDEST'],
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function criaFiltroReForfil($row){
        $filter = array(
	        array(
    		    "columnName" => "P_CDFORNECED", 
    		    "value" => $row['CDFORNECED'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_CDFILDEST", 
    		    "value" => $row['CDFILDEST'],
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function criaFiltroFornecedorOL($row){
        $filter = array(
	        array(
    		    "columnName" => "P_CDFORNOPELOG", 
    		    "value" => $row['CDFORNECED'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_CDFILDEST", 
    		    "value" => $row['CDFILDEST'],
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function criaFiltroParticMarca($row){
        $filter = array(
	        array(
    		    "columnName" => "P_CDPRODUTO", 
    		    "value" => $row['CDPRODUTO'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_CDFILIAL", 
    		    "value" => $row['CDFILDEST'],
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function criaFiltroProdPref($row){
        $filter = array(
	        array(
    		    "columnName" => "P_CDPRODUTO_OLD", 
    		    "value" => $row['CDPRODUTO_OLD'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_CDFILDEST", 
    		    "value" => $row['CDFILDEST'],
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function procedureCarrega_PeriForn($row){
        $procedure = new StoredProcedure($this->connection, 'CARREGA_PERIFORN');
        $procedure->addParam(new Param('P_CDFILIAL', Param::PARAM_INPUT, $row['CDFILDEST'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFORNECED', Param::PARAM_INPUT, $row['CDFORNECED'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_DTPROGENTAF', Param::PARAM_INPUT, $row['DTPROGENTAF'], Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NEW_DTPROGENTAF', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_STR, 10));
        return $procedure->execute();
    }
    
    public function criaFiltroVer_ProdComp($row){
        $filter = array(
	        array(
    		    "columnName" => "P_CDOPERADOR", 
    		    "value" => $row['CDOPERADOR'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_CDPRODUTO", 
    		    "value" => $row['CDARVPROD'],
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function salvarAF($row, $rowFornecedor, $fornecedorOL){
        if($row['IDTIPOLANCAF'] == null or $row['IDTIPOLANCAF'] == ''){
            $row['IDTIPOLANCAF'] = 'A';
        }
        if(sizeOf($fornecedorOL) > 0){
            $row['IDAFOPERLOG']  = '2';
            $row['CDFILIOPELOG'] = $fornecedorOL[0]['CDFILIAL'];
        } else {
            $row['IDAFOPERLOG']  = null;
            $row['CDFILIOPELOG'] = null; 
        }
        
        $nrautoforn = $this->NovoCodigo('AUTOFORNE');
        
        $params = array(
    		"CDFILDEST"     => $row['CDFILDEST'],
    		"CDFILLANC"     => $row['CDFILCENTCMP'],
    		"NRAUTOFORN"    => $nrautoforn,
    		"CDOPERADOR"    => $row['CDOPERADOR'],
    		"CDFORNECED"    => $row['CDFORNECED'],
    		"DTAUTOFORN"    => date('d/m/Y'),
    		"IDTIPOEMITAF"  => $row['IDTIPOEMITAF'],
    		"CDEMPRESA"     => $row['CDEMPRESA'],
    		"IDAFOPERLOG"   => $row['IDAFOPERLOG'],
    		"CDFILIOPELOG"  => $row['CDFILIOPELOG'],
    		"IDTIPOLANCAF"  => $row['IDTIPOLANCAF'],
    		"IDTPFORPGTAF"  => $rowFornecedor['IDTPFORPGTFO'],
    		"CDFORMPGTO"    => $rowFornecedor['CDFORMPGTO'],
    		"NRDIAPGFIXAF"  => $rowFornecedor['NRDIAPGFIXFO'],
    		"NRPARCPGTOAF"  => $rowFornecedor['NRPARCPGTOFO'],
    		"IDUTDIAPGTAF"  => $rowFornecedor['IDUTDIAPGTFO'],
    		"NRORG" => $this->environment->getNrorg()
    	);
    	try {
            $sql = "INSERT INTO AUTOFORNE(CDFILDEST, CDFILLANC, NRAUTOFORN, CDOPERADOR, CDFORNECED, DTAUTOFORN, CDFORMPGTO, IDTPFORPGTAF, IDTIPOEMITAF, CDEMPRESA, IDAFOPERLOG, CDFILIOPELOG, NRDIAPGFIXAF, NRPARCPGTOAF, IDUTDIAPGTAF, IDTIPOLANCAF, NRORG) VALUES (:CDFILDEST, :CDFILLANC, :NRAUTOFORN, :CDOPERADOR, :CDFORNECED, :DTAUTOFORN, :CDFORMPGTO, :IDTPFORPGTAF, :IDTIPOEMITAF, :CDEMPRESA, :IDAFOPERLOG, :CDFILIOPELOG, :NRDIAPGFIXAF, :NRPARCPGTOAF, :IDUTDIAPGTAF, :IDTIPOLANCAF, :NRORG)";
            $stmt = $this->connection->prepare($sql);
            $stmt->execute($params);
            return $nrautoforn;
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function salvarPrazoPgtAF($row, $nrautoforn){
        $params = array(
    		"P_CDFILDEST" => $row['CDFILDEST'],
    		"P_CDFILLANC" => $row['CDFILCENTCMP'],
    		"P_NRAUTOFORN" => $nrautoforn,
    		"P_CDFORNECED" => $row['CDFORNECED'],
    		"NRORG" => $this->environment->getNrorg()
    	);
    	try {
            $sql = "INSERT INTO PRAZOPGTAF(CDFILDEST, CDFILLANC, NRAUTOFORN, NRDIASPGTOAF, VRPERCPGTOAF, NRORG) (SELECT :P_CDFILDEST, :P_CDFILLANC, :P_NRAUTOFORN, NRDIASPGTOFO, VRPERCPGTOFO, :NRORG FROM PRAZOPGTFORN WHERE CDFORNECED = :P_CDFORNECED)";
            $stmt = $this->connection->prepare($sql);
            $stmt->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function criaFiltroItemAFNova($row, $nrautoforn){
        $filter = array(
	        array(
    		    "columnName" => "P_CDFILDEST", 
    		    "value" => $row['CDFILDEST'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_CDFILLANC", 
    		    "value" => $row['CDFILLANC'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_NRAUTOFORN", 
    		    "value" => $nrautoforn,
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_CDMARCA", 
    		    "value" => $row['CDMARCA_OLD'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_CDPRODUTO", 
    		    "value" => $row['CDPRODUTO_OLD'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_DTPROGENTAF", 
    		    "value" => $row['DTPROGENTAF_OLD'],
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function salvarItemAFMigracao($row, $nrautoforn, $itemAFNova){
        $dtentritmsol = null;
        if(sizeOf($itemAFNova) > 0){
    	    if($itemAFNova[0]['DTENTRITMSOL'] != null){
    	        $dtentritmsol = $itemAFNova[0]['DTENTRITMSOL'];    
    	    }
    	}
        $params = array(
    		"CDFILDEST" => $row['CDFILDEST'],
    		"CDFILLANC" => $row['CDFILCENTCMP'],
    		"NRAUTOFORN" => $nrautoforn,
    		"CDMARCA" => $row['CDMARCA'],
    		"CDPRODUTO" => $row['CDPRODUTO'],
    		"DTPROGENTAF" => $row['DTPROGENTAF'],
    		"QTPROGENTAF" => $this->valueToFloat($row['QTPROGENTAF']),
    		"VRPREUNIAF" => $this->valueToFloat($row['VRPREUNIAF']),
    		"CDFILDESTORIG" => $row['CDFILDEST'],
    		"CDFILLANCORIG" => $row['CDFILLANC'],
    		"NRAUTOFORNORIG" => $row['NRAUTOFORN'],
    		"CDPRODUTOORIG" => $row['CDPRODUTO_OLD'],
    		"CDMARCAORIG" => $row['CDMARCA_OLD'],
    		"DTPROGENTAFORIG" => $row['DTPROGENTAF_OLD'],
    		"DTENTRITMSOL" => $dtentritmsol,
    		"NRORG" => $this->environment->getNrorg()
    	);
    	try {
            $sql = "INSERT INTO ITEMAUTF(CDFILDEST, CDFILLANC, NRAUTOFORN, CDMARCA, CDPRODUTO, DTPROGENTAF, QTPROGENTAF, VRPREUNIAF, CDFILDESTORIG, CDFILLANCORIG, NRAUTOFORNORIG, DTENTRITMSOL, CDPRODUTOORIG, CDMARCAORIG, DTPROGENTAFORIG, NRORG) VALUES (:CDFILDEST, :CDFILLANC, :NRAUTOFORN, :CDMARCA, :CDPRODUTO, :DTPROGENTAF, :QTPROGENTAF, :VRPREUNIAF, :CDFILDESTORIG, :CDFILLANCORIG, :NRAUTOFORNORIG, :DTENTRITMSOL, :CDPRODUTOORIG, :CDMARCAORIG, :DTPROGENTAFORIG, :NRORG)";
            $stmt = $this->connection->prepare($sql);
            $stmt->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    // Adaptado de 'General.js'
    public function valueToFloat($value) {
		if (is_string($value) && $value) {
			if (strpos($value, ',') === false && strpos($value, '.') === false) {
				return floatval($value);
			} else if (strpos($value, ',') > strpos($value, '.')) {
                $value = str_replace('.', '', $value);
                $value = str_replace(',', '.', $value);
				return floatval($value);
			} else if (strpos($value, ',') < strpos($value, '.')) {
			    $value = str_replace(',', '.', $value);
				return floatval($value);
			}
		} else {
			return $value;
		}
    }
    
    public function updateItemAFMigra($row, $nrautoforn, $dbQtdOld){
        $params = array(
    		"P_CDFILDEST" => $row['CDFILDEST'],
    		"P_CDFILLANC" => $row['CDFILCENTCMP'],
    		"P_NRAUTOFORN" => $nrautoforn,
    		"P_CDMARCA" => $row['CDMARCA'],
    		"P_CDPRODUTO" => $row['CDPRODUTO'],
    		"P_DTPROGENTAF" => $row['DTPROGENTAF'],
    		"QTPROGENTAF" => $this->valueToFloat($dbQtdOld),
    		"NRORG" => $this->environment->getNrorg()
    	);
    	try {
            $sql = "UPDATE ITEMAUTF SET QTPROGENTAF = :QTPROGENTAF WHERE CDFILDEST = :P_CDFILDEST AND CDFILLANC = :P_CDFILLANC AND NRAUTOFORN = :P_NRAUTOFORN AND CDMARCA = :P_CDMARCA AND CDPRODUTO = :P_CDPRODUTO AND DTPROGENTAF = :P_DTPROGENTAF AND NRORG = :NRORG";
            $stmt = $this->connection->prepare($sql);
            $stmt->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function updateItemAFOrigem($row){
        $params = array(
    		"IDITEMIGRADO" => 'S',
    		"IDBAIXITMAF" => '3',
    		"P_CDFILDEST" => $row['CDFILDEST'],
    		"P_CDFILLANC" => $row['CDFILLANC'],
    		"P_NRAUTOFORN" => $row['NRAUTOFORN'],
    		"P_CDMARCA" => $row['CDMARCA_OLD'],
    		"P_CDPRODUTO" => $row['CDPRODUTO_OLD'],
    		"P_DTPROGENTAF" => $row['DTPROGENTAF_OLD'],
    		"NRORG" => $this->environment->getNrorg()
    	);
    	try {
            $sql = "UPDATE ITEMAUTF SET IDITAFMIGRADA = :IDITEMIGRADO, IDBAIXITMAF = :IDBAIXITMAF WHERE CDFILDEST = :P_CDFILDEST AND CDFILLANC = :P_CDFILLANC AND NRAUTOFORN = :P_NRAUTOFORN AND CDMARCA = :P_CDMARCA AND CDPRODUTO = :P_CDPRODUTO AND DTPROGENTAF = :P_DTPROGENTAF AND NRORG = :NRORG";
            $stmt = $this->connection->prepare($sql);
            $stmt->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function updateTpCtPagar($row){
        $params = array(
    		"P_CDFILDEST" => $row['CDFILDEST'],
    		"P_CDFILLANC" => $row['CDFILLANC'],
    		"P_NRAUTOFORN" => $row['NRAUTOFORN'],
    		"NRORG" => $this->environment->getNrorg()
    	);
    	try {
            $sql = "UPDATE AUTOFORNE SET CDTPCTPAGAR = ( SELECT PRODUTO.CDTPCTPAGAR FROM PRODUTO INNER JOIN ( SELECT MIN(CDPRODUTO) AS CDPRODUTO, NRORG FROM ( SELECT CDPRODUTO, MAX(QTPROGENTAF * VRPREUNIAF), NRORG FROM ITEMAUTF WHERE ITEMAUTF.CDFILDEST = :P_CDFILDEST AND ITEMAUTF.CDFILLANC = :P_CDFILLANC AND ITEMAUTF.NRAUTOFORN = :P_NRAUTOFORN AND ITEMAUTF.NRORG = :NRORG GROUP BY CDPRODUTO, NRORG HAVING MAX(QTPROGENTAF * VRPREUNIAF) = ( SELECT MAX(QTPROGENTAF * VRPREUNIAF) FROM ITEMAUTF WHERE ITEMAUTF.CDFILDEST = :P_CDFILDEST AND ITEMAUTF.CDFILLANC = :P_CDFILLANC AND ITEMAUTF.NRAUTOFORN = :P_NRAUTOFORN AND ITEMAUTF.NRORG = :NRORG ) ) GROUP BY NRORG ) ITEMAUTF ON PRODUTO.NRORG = ITEMAUTF.NRORG WHERE PRODUTO.CDPRODUTO = ( SELECT MAX(PROD.CDPRODUTO) FROM PRODUTO PROD WHERE PROD.NRORG = ITEMAUTF.NRORG AND ( INSTR(ITEMAUTF.CDPRODUTO, PROD.CDPRODUTO) = 1 ) AND PROD.CDTPCTPAGAR IS NOT NULL ) ), IDSTATLEITURA = 'N' WHERE AUTOFORNE.CDFILDEST = :P_CDFILDEST AND AUTOFORNE.CDFILLANC = :P_CDFILLANC AND AUTOFORNE.NRAUTOFORN = :P_NRAUTOFORN AND AUTOFORNE.NRORG = :NRORG AND AUTOFORNE.CDTPCTPAGAR IS NULL";
            $stmt = $this->connection->prepare($sql);
            $stmt->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function updateTpCtPagar1($row){
        $params = array(
    		"P_CDFILDEST" => $row['CDFILDEST'],
    		"P_CDFILLANC" => $row['CDFILLANC'],
    		"P_NRAUTOFORN" => $row['NRAUTOFORN']
    	);
    	try {
            $sql = "UPDATE AUTOFORNE SET CDTPCTPAGAR = NULL, IDSTATLEITURA   = 'N' WHERE AUTOFORNE.CDFILDEST  = :P_CDFILDEST AND AUTOFORNE.CDFILLANC  = :P_CDFILLANC AND AUTOFORNE.NRAUTOFORN = :P_NRAUTOFORN AND AUTOFORNE.CDTPCTPAGAR IS NOT NULL";
            $stmt = $this->connection->prepare($sql);
            $stmt->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    
    public function adqVerifCtPag($row) {
        $param = array(
            'P_NRAUTOFORN'  => $row['NRAUTOFORN'],
            'P_CDFILDEST'   => $row['CDFILDEST'],
            'P_CDFILLANC'   => $row['CDFILLANC']
        );
        
        $query = "SELECT COUNT( DISTINCT PROD.CDTPCTPAGAR) CONTA
                    FROM PRODUTO PROD, ITEMAUTF,
                         (SELECT P.CDPRODUTO, P.CDARVPROD,
                                 (SELECT NVL(MAX(PRODUTO.CDARVPROD), 'W')
                                    FROM PRODUTO
                                   WHERE PRODUTO.CDTPCTPAGAR IS NOT NULL
                                     AND PRODUTO.CDARVPROD = SUBSTR(P.CDARVPROD, 1, LENGTH(PRODUTO.CDARVPROD))) PRODTPCTPAGAR
                            FROM ITEMAUTF, PRODUTO P
                           WHERE ITEMAUTF.CDPRODUTO  = P.CDPRODUTO
                             AND ITEMAUTF.CDFILDEST  = :P_CDFILDEST
                             AND ITEMAUTF.CDFILLANC  = :P_CDFILLANC
                             AND ITEMAUTF.NRAUTOFORN = :P_NRAUTOFORN) I
                   WHERE I.PRODTPCTPAGAR     = PROD.CDARVPROD
                     AND ITEMAUTF.CDPRODUTO  = I.CDPRODUTO
                     AND ITEMAUTF.CDFILDEST  = :P_CDFILDEST
                     AND ITEMAUTF.CDFILLANC  = :P_CDFILLANC
                     AND ITEMAUTF.NRAUTOFORN = :P_NRAUTOFORN";
                   
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            
            $resultado = $std->fetchAll();
            
            return $resultado;
        } catch(Exception $e) {
            throw $e;
        }
    }
    
    public function procedureFechamentoAf($cdfildest, $cdfillanc, $nrautoforn){
        try {
            $procedure = new StoredProcedure($this->connection, 'FECHAMENTO_AF');
            $procedure->addParam(new Param('P_CDFILDEST', Param::PARAM_INPUT, $cdfildest, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDFILLANC', Param::PARAM_INPUT, $cdfillanc, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRAUTOFORN', Param::PARAM_INPUT, $nrautoforn, Param::PARAM_TYPE_STR));
            $procedure->execute();    
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function procedureExcluiContaPagarPrevista($cdfildest, $cdfillanc, $nrautoforn){
        try {
            $procedure = new StoredProcedure($this->connection, 'EXCLUI_CONTAPAGAR_PREVISTA');
            $procedure->addParam(new Param('P_CDFILDEST', Param::PARAM_INPUT, $cdfildest, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDFILLANC', Param::PARAM_INPUT, $cdfillanc, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRAUTOFORN', Param::PARAM_INPUT, $nrautoforn, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_RESULTADO', Param::PARAM_OUTPUT, null, Param::PARAM_TYPE_STR, 100));
            return $procedure->execute();    
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function procedureGeraContaPagarPrevista($cdfildest, $cdfillanc, $nrautoforn){
        try {
            $procedure = new StoredProcedure($this->connection, 'GERA_CONTAPAGAR_PREVISTA');
            $procedure->addParam(new Param('P_CDFILDEST', Param::PARAM_INPUT, $cdfildest, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDFILLANC', Param::PARAM_INPUT, $cdfillanc, Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRAUTOFORN', Param::PARAM_INPUT, $nrautoforn, Param::PARAM_TYPE_STR));
            $procedure->execute();    
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function filtroAF($row){
        $filter = array(
	        array(
    		    "columnName" => "P_CDFILDEST", 
    		    "value" => $row['CDFILDEST'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_CDFILLANC", 
    		    "value" => $row['CDFILLANCORIG'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_NRAUTOFORN", 
    		    "value" => $row['NRAUTOFORNORI'],
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function updateBaixaAf($row, $idBaixaAF){
        $params = array(
            "IDBAIXAAF" => $idBaixaAF,
    		"P_CDFILDEST" => $row['CDFILDEST'],
    		"P_CDFILLANC" => $row['CDFILLANCORIG'],
    		"P_NRAUTOFORN" => $row['NRAUTOFORNORI'],
    		"NRORG" => $this->environment->getNrorg()
    	);
    	try {
            $sql = "UPDATE AUTOFORNE SET IDBAIXAAF = :IDBAIXAAF WHERE CDFILDEST = :P_CDFILDEST AND CDFILLANC = :P_CDFILLANC AND NRAUTOFORN = :P_NRAUTOFORN AND NRORG = :NRORG";
            $stmt = $this->connection->prepare($sql);
            $stmt->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function procedureAjusteContaPrevista($row){
        try {
            $procedure = new StoredProcedure($this->connection, 'AJUSTE_CONTPREVISTA');
            $procedure->addParam(new Param('P_CDFILDEST', Param::PARAM_INPUT, $row['CDFILDEST'], Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_CDFILLANC', Param::PARAM_INPUT, $row['CDFILLANCORIG'], Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRAUTOFORN', Param::PARAM_INPUT, $row['NRAUTOFORNORI'], Param::PARAM_TYPE_STR));
            $procedure->execute();    
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function filtroFornOLProduto($row){
        $filter = array(
	        array(
    		    "columnName" => "P_CDFORNOPELOG", 
    		    "value" => $row['CDFORNECED'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_CDFILDEST", 
    		    "value" => $row['CDFILDEST'],
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function filtroPesqProduto($row){
        $filter = array(
	        array(
    		    "columnName" => "P_CDFILCENTCMP", 
    		    "value" => $row['CDFILCENTCMP'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_CDPRODOLD", 
    		    "value" => $row['CDPRODUTO_OLD'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_CDARVPROD", 
    		    "value" => $row['CDARVPROD'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_CDFORNECED", 
    		    "value" => $row['CDFORNECED'],
    		    "operator" => "="
    		),
	        array(
    		    "columnName" => "P_CDFORNOPELOG", 
    		    "value" => $row['CDFORNOPELOG'],
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function gravaError($error, $arrayError){
        if($error['DSERROR'] != null) {
            array_push($arrayError, $error);
            $error['DSERROR'] = null;
        }
        return $arrayError;
    }
    
    private function replaceMessages($dserror, $messages)
    {
        foreach($messages as $message) {
            if($message['codeError'] === $dserror) {
                return $message['msgError'];
            }
        }
    }
    
    public function preencheDsError($row, $dserror, $messages){
        $error['DSERROR']     = $this->replaceMessages($dserror, $messages);
        $error['CDARVPROD']   = $row['CDARVPROD'];
        $error['NMPRODUTO']   = $row['NMPRODUTO'];
        $error['DTPROGENTAF'] = $row['DTPROGENTAF'];
        $error['__is_new']    = False;
        return $error;
    }
    
    public function filtroMarcaProduto($row){
        $filter = array(
	        array(
    		    "columnName" => "P_CDARVPROD", 
    		    "value" => $row['CDARVPROD'],
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "P_CDMARCA", 
    		    "value" => $row['CDMARCA'],
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function filtroProduto($rows){
        $stFilDest = '_';
        $stFilLanc = '_';
        $stNrAutoF = '_';
        foreach ($rows as $row) {
            $stFilDest .= $row['CDFILDEST'] .'_';
            $stFilLanc .= $row['CDFILLANC'] .'_';
            $stNrAutoF .= $row['NRAUTOFORN'] .'_';
            $stProdIni = $row['CDPRODINI'];
            $stProdFin = $row['CDPRODFIN'];
            $dtProgIni = $row['DTPROGENTAFINI'];
            $dtProgFin = $row['DTPROGENTAFFIN'];
            $stGeraRup = $row['IDTPGERARUP'];
        }
        $filter = array(
	        array(
    		    "columnName" => "P_CDFILDEST", 
    		    "value" => $stFilDest,
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "P_CDFILLANC", 
    		    "value" => $stFilLanc,
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "P_NRAUTOFORN", 
    		    "value" => $stNrAutoF,
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "P_CDPRODINI", 
    		    "value" => $stProdIni,
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "P_CDPRODFIN", 
    		    "value" => $stProdFin,
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "P_DTPROGENTAFINI", 
    		    "value" => $dtProgIni,
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "P_DTPROGENTAFFIN", 
    		    "value" => $dtProgFin,
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "P_IDTPGERARUP", 
    		    "value" => $stGeraRup,
    		    "operator" => "="
    		),
    		array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	
    	return $filter;
    }
    
    public function getComprador($row) {
        $params = array(
            "P_CDFILDEST" => $row['CDFILDEST'] ,
            "P_CDFILLANC" => $row['CDFILLANC'],
            "P_NRAUTOFORN" => $row['NRAUTOFORN']
    	);
    	$query = "SELECT CDOPERADOR FROM AUTOFORNE WHERE CDFILDEST  = :P_CDFILDEST AND CDFILLANC = :P_CDFILLANC AND NRAUTOFORN = :P_NRAUTOFORN";
		try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            $resultado = $std->fetchAll();
            return $resultado;
        } catch (Exception $e){
            throw $e;
        }
    }
}