/************************************************************************************
    Trigger para registro na logopera das alteraes feitas na retirada da produo
*************************************************************************************

Criado em  : 09/11/2024
       Por : Jeferson Araujo
Descrio: Registra na logopera em casos de INSERT, UPDATE e DELETE na tabela RETIRADAESTO. 

Trigger: 9967_CDPTRGO_LOG_CDP_RETIRADAESTO
Util   : Erro : raise_application_error(-20501, 'Mensagem', True);
*/
create or replace TRIGGER LOG_CDP_RETIRADAESTO AFTER 
    DELETE OR INSERT OR UPDATE ON RETIRADAESTO 
    FOR EACH ROW 
 
DECLARE 
    V_USUARIO           VARCHAR2(40); 
    V_TIPO              VARCHAR2(1); 
    V_ITPESQ            VARCHAR2(40); 
    V_DESC              VARCHAR2(4000); 
    V_CDFILLOGOPER      VARCHAR2(4); 
    V_DSREMOTEADDR      VARCHAR2(15); 
    V_DSREMOTEHOST      VARCHAR2(15); 
    V_DSSERVERRDM       VARCHAR2(20); 
    V_DSSERVMETHOD      VARCHAR2(30); 
    V_DSREMOTEOPER      VARCHAR2(12); 
    V_DTOPER            DATE; 
    V_TAM               INTEGER; 
BEGIN 

    V_TIPO         := '0'; 
    V_DESC         := ''; 
    V_CDFILLOGOPER := ''; 

    IF DELETING THEN

        IF :OLD.CDFILIAL IS NOT NULL THEN 
            V_DESC := V_DESC|| ' Cod.Filial='|| :OLD.CDFILIAL; 
        END IF; 

        IF :OLD.NRRETEST IS NOT NULL THEN 
            V_DESC := V_DESC|| ' Nr.Ret.Est='|| :OLD.NRRETEST; 
        END IF; 

        IF :OLD.NRLANCESTQ IS NOT NULL THEN 
            V_DESC := V_DESC || ' Lanc.Estq='|| :OLD.NRLANCESTQ; 
        END IF; 

        IF :OLD.NRORDPROD IS NOT NULL THEN 
            V_DESC := V_DESC|| ' Nr.Ord.Produo='|| :OLD.NRORDPROD; 
        END IF; 

        IF :OLD.NRSUBORDPROD IS NOT NULL THEN 
            V_DESC := V_DESC|| ' Nr.Sub.OrdProd='|| :OLD.NRSUBORDPROD; 
        END IF; 

        IF :OLD.CDETAPAPROD IS NOT NULL THEN 
            V_DESC := V_DESC|| ' Cod.EtapaProd.='|| :OLD.CDETAPAPROD; 
        END IF; 

        IF :OLD.NRREQUESTO IS NOT NULL THEN 
            V_DESC := V_DESC|| ' Qt.Ext='|| :OLD.NRREQUESTO; 
        END IF; 

        IF :OLD.DTRETEST IS NOT NULL THEN 
            V_DESC := V_DESC|| ' Dt.Ret.Est='|| :OLD.DTRETEST; 
        END IF; 

        IF :OLD.DSRETEST IS NOT NULL THEN 
            V_DESC := V_DESC|| ' Desc.Ret.Est='|| :OLD.DSRETEST; 
        END IF; 

        IF :OLD.CDFILIALLAN IS NOT NULL THEN 
            V_DESC := V_DESC || ' Filial.Lanc.='|| :OLD.CDFILIALLAN; 
        END IF; 

        IF :OLD.CDSETOR IS NOT NULL THEN 
            V_DESC := V_DESC || ' Cod.Setor='|| :OLD.CDSETOR; 
        END IF; 

        IF :OLD.CDCENTCUST IS NOT NULL THEN 
            V_DESC := V_DESC|| ' Cod.Cent.Custo='|| :OLD.CDCENTCUST; 
        END IF; 

        IF :OLD.IDPESPRODRET IS NOT NULL THEN 
            V_DESC := V_DESC|| ' Id.PesoProd.Ret='|| :OLD.IDPESPRODRET; 
        END IF; 

        IF :OLD.CDFILIALORE IS NOT NULL THEN 
            V_DESC := V_DESC||' Filial O.R.E= '|| :OLD.CDFILIALORE; 
        END IF; 

        IF :OLD.NRORCAEVENTO IS NOT NULL THEN 
            V_DESC := V_DESC || ' Nr.OrcaEvento='|| :OLD.NRORCAEVENTO; 
        END IF; 

        IF :OLD.NRSEQORCAEVE IS NOT NULL THEN 
            V_DESC := V_DESC || ' Nr.Seq. OrcaEvento='|| :OLD.NRSEQORCAEVE; 
        END IF; 

        IF :OLD.IDRETIRAPERDA IS NOT NULL THEN 
            V_DESC := V_DESC|| ' Id.Reti.Perda='|| :OLD.IDRETIRAPERDA; 
        END IF; 

        V_TIPO         := '3'; 
        V_ITPESQ       := :OLD.CDFILIAL|| :OLD.NRRETEST;
        V_CDFILLOGOPER := :OLD.CDFILIAL; 
    ELSE 
        IF UPDATING THEN 

            IF NVL(:NEW.CDFILIAL, '!') <> NVL(:OLD.CDFILIAL, '!') THEN 
                V_DESC := V_DESC|| ' Cod.Filial='|| :NEW.CDFILIAL; 
            END IF; 

            IF NVL(:NEW.NRLANCESTQ, '!') <> NVL(:OLD.NRLANCESTQ, '!') THEN 
                V_DESC := V_DESC || ' Lanc.Estq='|| :NEW.NRLANCESTQ; 
            END IF; 

            IF :OLD.NRRETEST IS NOT NULL THEN 
                V_DESC := V_DESC|| ' referente ao Nr.Ret.Est='|| :OLD.NRRETEST; 
            END IF;

            IF NVL(:NEW.NRORDPROD, '!') <> NVL(:OLD.NRORDPROD, '!') THEN 
                V_DESC := V_DESC|| ' Nr.Ord.Produo='|| :NEW.NRORDPROD; 
            END IF; 

            IF NVL(:NEW.NRSUBORDPROD, '!') <> NVL(:OLD.NRSUBORDPROD, '!') THEN 
                V_DESC := V_DESC|| ' Nr.Sub.OrdProd='|| :NEW.NRSUBORDPROD; 
            END IF; 

            IF NVL(:NEW.CDETAPAPROD, '!') <> NVL(:OLD.CDETAPAPROD, '!') THEN 
                V_DESC := V_DESC|| ' Cod.EtapaProd.='|| :NEW.CDETAPAPROD; 
            END IF; 

            IF NVL(:NEW.NRREQUESTO, '!') <> NVL(:OLD.NRREQUESTO, '!') THEN 
                V_DESC := V_DESC|| ' Qt.Ext='|| :NEW.NRREQUESTO; 
            END IF; 

            IF NVL(:NEW.DTRETEST, SYSDATE) <> NVL(:OLD.DTRETEST, SYSDATE) THEN 
                V_DESC := V_DESC|| ' Dt.Ret.Est='|| :NEW.DTRETEST; 
            END IF; 

            IF NVL(:NEW.DSRETEST, '!') <> NVL(:OLD.DSRETEST, '!') THEN 
                V_DESC := V_DESC|| ' Desc.Ret.Est='|| :NEW.DSRETEST; 
            END IF; 

            IF NVL(:NEW.CDFILIALLAN, '!') <> NVL(:OLD.CDFILIALLAN, '!') THEN 
                V_DESC := V_DESC || ' Filial.Lanc.='|| :NEW.CDFILIALLAN; 
            END IF; 

            IF NVL(:NEW.CDSETOR, '!') <> NVL(:OLD.CDSETOR, '!') THEN 
                V_DESC := V_DESC || ' Cod.Setor='|| :NEW.CDSETOR; 
            END IF; 

            IF NVL(:NEW.CDCENTCUST, '!') <> NVL(:OLD.CDCENTCUST, '!') THEN  
                V_DESC := V_DESC|| ' Cod.Cent.Custo='|| :NEW.CDCENTCUST; 
            END IF; 

            IF NVL(:NEW.IDPESPRODRET, '!') <> NVL(:OLD.IDPESPRODRET, '!') THEN 
                V_DESC := V_DESC|| ' Id.PesoProd.Ret='|| :NEW.IDPESPRODRET; 
            END IF; 

            IF NVL(:NEW.CDFILIALORE, '!') <> NVL(:OLD.CDFILIALORE, '!') THEN  
                V_DESC := V_DESC||' Filial O.R.E= '|| :NEW.CDFILIALORE; 
            END IF; 

            IF NVL(:NEW.NRORCAEVENTO, '!') <> NVL(:OLD.NRORCAEVENTO, '!') THEN  
                V_DESC := V_DESC || ' Nr.OrcaEvento='|| :NEW.NRORCAEVENTO; 
            END IF; 

            IF NVL(:NEW.NRSEQORCAEVE, '!') <> NVL(:OLD.NRSEQORCAEVE, '!') THEN 
                V_DESC := V_DESC || ' Nr.Seq. OrcaEvento='|| :NEW.NRSEQORCAEVE; 
            END IF; 

            IF NVL(:NEW.IDRETIRAPERDA, '!') <> NVL(:OLD.IDRETIRAPERDA, '!') THEN 
                V_DESC := V_DESC|| ' Id.Reti.Perda='|| :NEW.IDRETIRAPERDA; 
            END IF; 

            V_TIPO         := '2'; 
            V_ITPESQ       := :OLD.CDFILIAL|| :OLD.NRRETEST; 
            V_CDFILLOGOPER := :OLD.CDFILIAL; 

        ELSE 

            IF :NEW.CDFILIAL IS NOT NULL THEN 
                V_DESC := V_DESC|| ' Cod.Filial='|| :NEW.CDFILIAL; 
            END IF; 

            IF :NEW.NRRETEST IS NOT NULL THEN 
                V_DESC := V_DESC|| ' Nr.Ret.Est='|| :NEW.NRRETEST; 
            END IF; 

            IF :NEW.NRLANCESTQ IS NOT NULL THEN 
                V_DESC := V_DESC || ' Lanc.Estq='|| :NEW.NRLANCESTQ; 
            END IF; 

            IF :NEW.NRORDPROD IS NOT NULL THEN 
                V_DESC := V_DESC|| ' Nr.Ord.Produo='|| :NEW.NRORDPROD; 
            END IF; 

            IF :NEW.NRSUBORDPROD IS NOT NULL THEN 
                V_DESC := V_DESC|| ' Nr.Sub.OrdProd='|| :NEW.NRSUBORDPROD; 
            END IF; 

            IF :NEW.CDETAPAPROD IS NOT NULL THEN 
                V_DESC := V_DESC|| ' Cod.EtapaProd.='|| :NEW.CDETAPAPROD; 
            END IF; 

            IF :NEW.NRREQUESTO IS NOT NULL THEN 
                V_DESC := V_DESC|| ' Qt.Ext='|| :NEW.NRREQUESTO; 
            END IF; 

            IF :NEW.DTRETEST IS NOT NULL THEN 
                V_DESC := V_DESC|| ' Dt.Ret.Est='|| :NEW.DTRETEST; 
            END IF; 

            IF :NEW.DSRETEST IS NOT NULL THEN 
                V_DESC := V_DESC|| ' Desc.Ret.Est='|| :NEW.DSRETEST; 
            END IF; 

            IF :NEW.CDFILIALLAN IS NOT NULL THEN 
                V_DESC := V_DESC || ' Filial.Lanc.='|| :NEW.CDFILIALLAN; 
            END IF; 

            IF :NEW.CDSETOR IS NOT NULL THEN 
                V_DESC := V_DESC || ' Cod.Setor='|| :NEW.CDSETOR; 
            END IF; 

            IF :NEW.CDCENTCUST IS NOT NULL THEN 
                V_DESC := V_DESC|| ' Cod.Cent.Custo='|| :NEW.CDCENTCUST; 
            END IF; 

            IF :NEW.IDPESPRODRET IS NOT NULL THEN 
                V_DESC := V_DESC|| ' Id.PesoProd.Ret='|| :NEW.IDPESPRODRET; 
            END IF; 

            IF :NEW.CDFILIALORE IS NOT NULL THEN 
                V_DESC := V_DESC||' Filial O.R.E= '|| :NEW.CDFILIALORE; 
            END IF; 

            IF :NEW.NRORCAEVENTO IS NOT NULL THEN 
                V_DESC := V_DESC || ' Nr.OrcaEvento='|| :NEW.NRORCAEVENTO; 
            END IF; 

            IF :NEW.NRSEQORCAEVE IS NOT NULL THEN 
                V_DESC := V_DESC || ' Nr.Seq. OrcaEvento='|| :NEW.NRSEQORCAEVE; 
            END IF; 

            IF :NEW.IDRETIRAPERDA IS NOT NULL THEN 
                V_DESC := V_DESC|| ' Id.Reti.Perda='|| :NEW.IDRETIRAPERDA; 
            END IF;

            V_TIPO         := '1'; 
            V_ITPESQ       := :NEW.CDFILIAL || :NEW.NRRETEST; 
            V_CDFILLOGOPER := :NEW.CDFILIAL; 

        END IF; 
    END IF; 

    IF V_TIPO <> '0' THEN 

        NMUSUARIO(V_USUARIO); 
        WEBTUNNING(V_DSREMOTEADDR, V_DSREMOTEHOST, V_DSSERVERRDM, V_DSSERVMETHOD, V_DSREMOTEOPER); 
        IF NOT V_DESC IS NULL THEN 
            V_TAM := LENGTH(V_DESC); 
            WHILE ( V_TAM >= 0 ) LOOP 
                V_DTOPER := SYSDATE; 
                INSERT INTO LOGOPERA ( 
                    NMTABELA, 
                    DTOPERACAO, 
                    NMRESPOPER, 
                    IDTIPOOPER, 
                    CDPESQITEM, 
                    DSOPERACAO, 
                    CDFILLOGOPER, 
                    DSRDMUSUOPER, 
                    DSENDUSUOPER, 
                    DSNMUSUOPER, 
                    DSMETUSUOPER, 
                    CDORESPOPER 
                ) VALUES ( 
                    'RETIRADAESTO', 
                    V_DTOPER, 
                    V_USUARIO, 
                    V_TIPO, 
                    V_ITPESQ, 
                    SUBSTR(V_DESC, 1, 300), 
                    V_CDFILLOGOPER, 
                    V_DSSERVERRDM, 
                    V_DSREMOTEADDR, 
                    V_DSREMOTEHOST, 
                    V_DSSERVMETHOD, 
                    V_DSREMOTEOPER 
                ); 
                V_DESC := SUBSTR(V_DESC, 300, V_TAM); 
                V_TAM  := LENGTH(V_DESC); 
            END LOOP; 
        END IF; 
    END IF; 
END; 

/
-- VERSAO --
BEGIN ATUVEROBJ('LOG_CDP_RETIRADAESTO','6.49.037'); END;
/

